#!/bin/bash
#* Hardware information
# - number of cpu cores    -------------                          -- DONE
# - number of online cpu cores  ---------                         -- DONE
# - type of cpu cores           ---------                         -- DONE
# - total amount of ram         ---------                         -- DONE
# - virtual or physical?        ---------                         -- DONE
#          
#* Corefiles (if any)
#* Merlin config		        ---------                         -- DONE
#* Object config (anonymised, for preference)                     -- MISSED
#* A ton of logfiles            ---------                         -- DONE
#* Output/result of:
# - mysqlcheck on any and all databases --                        -- DONE
# - "netstat -tpan", run over a few seconds                       -- DONE
# - uptime                ------------------                      -- DONE
# - atop, sampled over a few seconds                              -- MISSED
# - disk I/O throughput test (hdparm -tT $all_disks)              -- DONE
# - disk random access times                                      -- DONE
# - memory random access times                                    -- MISSED
# - free                                                          -- DONE
# - top memory eaters and their pmaps                             -- DONE 
# - any and all hardware checks shipped from server manufacturer  -- MISSED

if [ "$1" == "debug" ];
then
to="andriy.humenetskyy@n-ix.com.ua"
else
to="support@op5.com"
fi

mail_path="/opt/op5sys/var/support/"
message_file="/tmp/support_message"
attaches=""

#if no new letters than exit
if [ "$(ls $mail_path)" == "" ];
then
	exit 0	
fi
 #current timestamp
T="$(date +%s)"


number_of_cpu_cores="Number of cpu cores: "$(grep -c ^processor /proc/cpuinfo)"\n"
number_of_online_cpu_cores=0


function number_of_online_cpu_cores()
{
    local cpu_folder="/sys/devices/system/cpu/"
    local count=0
    local value=''
    for cpu in $(ls $cpu_folder | grep cpu[0-9]*$)
    do
	if [ -f $cpu_folder$cpu/online ];
	then
	    value=$(cat $cpu_folder$cpu/online)
	    if [ $value -eq "1" ];
	    then
		count=$(($count+1))
	    fi
	else 
	    #possible case when no "online" file
	    count=$(($count+1))
	fi
    done
    number_of_online_cpu_cores="Number of online CPU cores: "$count"\n"
}

function add_attachment_file
{
    if [ -f $1 ];
    then
	#cat $1 >> $message_file
	attaches=$attaches"-a $1 "
    fi    
}

function parse_request_file
{
    request_email=""
    request_subject=""
    request_message=""
    
    request_email=$(head -1 $1)
    request_subject=$(head -2 $1 | tail -1)
    request_message=$(sed "1,2d" $1)
}


total_amount_of_ram="Total amount of physical RAM: "$(grep MemTotal /proc/meminfo | awk '{print $2" "$3}')"\n"
total_amount_of_swap="Total amount of Swap RAM: "$(grep SwapTotal /proc/meminfo | awk '{print $2" "$3}')"\n"

type_of_cpu_cores=$(grep "model name" /proc/cpuinfo)


number_of_online_cpu_cores


echo -e $number_of_cpu_cores"\n" > $message_file
echo -e $number_of_online_cpu_cores"\n" >> $message_file
echo -e $type_of_cpu_cores"\n" >> $message_file
echo -e $total_amount_of_ram"\n" >> $message_file
echo -e $total_amount_of_swap"\n" >> $message_file



if [ -d /opt/monitor/op5/merlin/logs ];
then
    tar -cvzf /tmp/op5_monitor_logs.tgz /opt/monitor/op5/merlin/logs
    add_attachment_file /tmp/op5_monitor_logs.tgz
fi

add_attachment_file /opt/monitor/op5/merlin/merlin.conf
add_attachment_file /var/log/messages
add_attachment_file /var/log/httpd/error_log
add_attachment_file /var/log/httpd/ssl_error_log


#mysqlcheck for all databases
echo -e "mysqlcheck for all databases">>$message_file
echo -e $(mysqlcheck --all-databases)>>$message_file
echo -e "\n">>$message_file


echo "Mysqlcheck for every database">>$message_file
for database in $(mysql -e "show databases;" |grep -v ^Database$)
do
    echo -e "Database: $database">>$message_file
    echo -e $(mysqlcheck --databases $database)>>$message_file
done
echo -e "\n">>$message_file

#"netstat -tpan"
echo -e "'netstat -tpan':">>$message_file
echo -e $(netstat -tpan)"\n">>$message_file

#"uptime"
echo -e "'uptime':">>$message_file
echo -e $(uptime)"\n">>$message_file

mkdir /tmp/discs_$T
echo -e "Disc I/O throughput test:">>$message_file
discs=$(cat /proc/partitions | awk '{print $4}')
for disc in $discs
do
    if [ "$disc" != "name" ]; 
    then
		( /sbin/hdparm -tT /dev/$disc 2>&1 ) >> /tmp/discs_$T/hdparm.$disk
    fi
done
cat /tmp/discs_$T/hdparm.* >> $message_file
rm -Rf /tmp/discs_$T
echo -e "\n">>$message_file


#disc random access times
echo -e "disc random access times:">>$message_file
echo -e $(iostat -h)"\n">>$message_file


#free
echo -e "free:">>$message_file
echo -e $(free)"\n">>$message_file


#top memory eaters and their pmaps
echo -e "top memory eaters and their pmaps:">>$message_file
echo -e $(ps aux | sort -nrk 4 | head)"\n">>$message_file



for mail in $(ls $mail_path)
do
    #get email, subject and messaage from file
    parse_request_file $mail_path$mail

    #sending email, using mutt
    export EMAIL
    old_email=$EMAIL
    EMAIL="op5 feedback <$request_email>"
    mutt  -s "$request_subject" -a $message_file $attaches $to <<< "$request_message"
    EMAIL=$old_email #!!!must reset this value
    rm -f $mail_path$mail
done