<?php
	function gVal(& $var, $key, $default = NULL) {
		return isset($var[$key]) ? $var[$key] : $default;
	}
	
	function validEmail($email)
	{
	    $isValid = true;
	    $atIndex = strrpos($email, "@");
	    if (is_bool($atIndex) && !$atIndex)
	    {
		$isValid = false;
	    }
	    else
	    {
		$domain = substr($email, $atIndex+1);
		$local = substr($email, 0, $atIndex);
		$localLen = strlen($local);
		$domainLen = strlen($domain);
		if ($localLen < 1 || $localLen > 64)
		{
            	    // local part length exceeded
        	     $isValid = false;
                }
                else if ($domainLen < 1 || $domainLen > 255)
                {
            	    // domain part length exceeded
                $isValid = false;
                }
                else if ($local[0] == '.' || $local[$localLen-1] == '.')
                {
            	    // local part starts or ends with '.'
                    $isValid = false;
                }
                else if (preg_match('/\\.\\./', $local))
                {
            	    // local part has two consecutive dots
                    $isValid = false;
                }
                else if (!preg_match('/^[A-Za-z0-9\\-\\.]+$/', $domain))
                {
            	    // character not valid in domain part
                    $isValid = false;
                }
                else if (preg_match('/\\.\\./', $domain))
                {
            	    // domain part has two consecutive dots
                     $isValid = false;
                 }
                else if (!preg_match('/^(\\\\.|[A-Za-z0-9!#%&`_=\\/$\'*+?^{}|~.-])+$/', str_replace("\\\\","",$local)))                                                                                                                                                                                                                                                                                                        {
            	    // character not valid in local part unless 
            	    // local part is quoted
                    if (!preg_match('/^"(\\\\"|[^"])+"$/',str_replace("\\\\","",$local)))
                    {
                	$isValid = false;
                    }
                }
                if ($isValid && !(checkdnsrr($domain,"MX") || checkdnsrr($domain,"A")))
                {
                // domain not found in DNS
                $isValid = false;
                }
            }
        return $isValid;
     }	
	
    function createRequest($subject, $email, $message)
    {
	$path = '/opt/op5sys/var/support/';
	if(!is_dir($path)) throw new Exception('Cannot create request. Request\'s folder does not exist.');
	if(!is_writable($path)) throw new Exception('Cannot create request. No permissions on request\'s folder.');
	
	//create file
	$request_file = $path.time().".request";
	$f = fopen($request_file, 'w');
	if(!$f) throw new Exception('Cannot create request file.');
	fwrite($f, $email."\n");
	fwrite($f, $subject."\n");
	fwrite($f, $message);
	fclose($f);
	
    }
	
	
	
	if (isset($_POST["send"])) {
		$subject = gVal($_POST, "feedback-subject", "op5 Portal feedback");
		$content = gVal($_POST, "feedback-content", "");
		$email = gVal($_POST, "feedback-email", "");
		try {
			if(!validEmail($email)) throw new Exception('Incorrect email address.');
			createRequest($subject, $email, $content);
		} catch(Exception $e) {
			header('Location: /feedback.php?result=failure&msg='.urlencode($e->getMessage()));
			die();
		}
		header('Location: /feedback.php?result=success');
		die();
	}
	$result = gVal($_GET, "result", NULL);
	$msg = gVal($_GET, "msg", NULL);

	$web_conf = true;
	$settings_lib_path = "/opt/op5sys/lib/php/op5settings.php";
	if (file_exists($settings_lib_path) && is_readable($settings_lib_path)) {
		require_once($settings_lib_path);
		$web_conf = !(strtoupper(op5settings::inst()->webconfig) === "FALSE");
	}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
	<meta http-equiv="Content-type" content="application/xhtml+xml; charset=iso-8859-2" />
	<meta http-equiv="cache-control" content="no-cache" />
	<title> Welcome to op5 Portal </title>
	<link type="text/css" rel="stylesheet" href="portal/css/common.css" />
	<link type="text/css" rel="stylesheet" href="portal/css/ids.css" />
	<link type="text/css" rel="stylesheet" href="portal/css/classes.css" />
	<script type="text/javascript" src="portal/js/load_css.js"></script>
	<script type="text/javascript" src="portal/js/script.js"></script>
	<script type="text/javascript" src="portal/js/ajax.js"></script>
	<script type="text/javascript" src="portal/js/help.js"></script>
	<script type="text/javascript" src="portal/js/help_texts.js"></script>
	<link type="image/ico" rel="icon" href="portal/images/op5.ico" />
</head>
<body>
	<div id="container">
		<div id="logo">
			<h1>op5 Portal</h1>
		</div>

		<div id="top-menu">
			<ul>
				<li><a href="/">Start</a></li>
				<?php $rpmstatus = 1;
				@system('rpm -q op5config --quiet', $rpmstatus);
				if (($rpmstatus == 0) && (TRUE === $web_conf) ): ?>
				<li><a href="/op5config">Configure System</a></li>
				<?php endif; ?>
				<li><a href="/about.php">About</a></li>
				<li><a href="/feedback.php" class="selected">Support</a></li>
				<li><a href="#" onclick="window.open('http://www.op5.com')">op5.com</a></li>
			</ul>
		</div>

		<div id="navbar">
		<?php include 'updates_bar.php'; ?>
		</div>
		<div id="content">
			<?php if($result === NULL) { ?>
			<h1>SUPPORT</h1>
			<p>When purchasing our products you also get access to our support services. op5 provide product support that goes well beyond what you experience with other commercial software companies &mdash; delivered by people with years of industry experience. The op5 Support Team is a team of highly skilled software engineers with several years experience in system administration and system integration. The team members have a deep understanding of our software applications. Each of our support engineers is certified for our solutions and is backed by the engineering team who designed and developed the product. Armed with this expertise, we are able to resolve issues quickly.</p>
			<form action="/feedback.php" method="POST" id="mail-send-form">
				<table summary="Send Mail" style="border: none;">
					<colgroup>
						<col class="td_column_name">
						<col class="auto">
					</colgroup>
					<tbody>
						<tr id="message">
							<td colspan="2">&nbsp;</td>
						</tr>
						<tr>
							<td><a href="#" onclick="help('feedback-subject')">[?]</a> <label for="feedback-subject">Subject</label></td>
							<td><input type="text" name="feedback-subject" id="feedback-subject" class="normal"/></td>
						</tr>
						<tr>
							<td><a href="#" onclick="help('feedback-email')">[?]</a> <label for="feedback-email">Email</label></td>
							<td><input type="text" name="feedback-email" id="feedback-email" class="normal"/></td>
						</tr>
						<tr>
							<td style="vertical-align: top;"><a href="#" onclick="help('feedback-content')">[?]</a> <label for="feedback-content">Content</label></td>
							<td><textarea id="feedback-content" name="feedback-content" class="normal" style="width: 97.5%; height: 150px"></textarea></td>
						</tr>
						<tr>
							<td>&nbsp;</td>
							<td>
								<input type="submit" name="send" value="Send Mail">
							</td>
						</tr>
					</tbody>
				</table>
			</form>
			<?php } elseif ($result === "success") { ?>
			<h1 class="ok">Message successfully sent.</h1>
			<p>When purchasing our products you also get access to our support services. op5 provide product support that goes well beyond what you experience with other commercial software companies &mdash; delivered by people with years of industry experience.</p>
			<?php } else { ?>
			<h1 class="error">Send message failure.</h1>
			<p>Sorry, some error occurred during sending the message.</p>
			<?php if($msg) { ?>
			<p style="color: #B44;"><b style="color: #B00;">Error: </b><?php print $msg; ?></p>
			<?php } ?>
			<?php } ?>
		</div>
	</div>
</body>
